@@ -47,6 +47,10 @@ class PromptHandler:
                 return await self._handle_certcpp_check()
             elif name == "check_custom":
                 return await self._handle_custom_check()
+            elif name == "check_cim_static":
+                return await self._handle_cim_static_check()
+            elif name == "check_cim_misra_cpp":
+                return await self._handle_cim_misra_cpp_check()
             elif name == "check_races":
                 return await self._handle_race_condition_analysis(arguments)
             elif name == "check_leaks":
@@ -65,6 +69,8 @@ class PromptHandler:
                 return await self._handle_reset_race_check_prompt(arguments)
             elif name == "check_design":
                 return await self._handle_design_check(arguments)
+            elif name == "check_single_requirement":
+                return await self._handle_single_requirement(arguments)
             else:
                 raise ValueError(f"Unknown prompt: {name}")
                 
@@ -72,6 +78,32 @@ class PromptHandler:
             logger.exception(f"Error in prompt handler for {name}: {e}")
             raise
     
+    async def _handle_single_requirement(self, arguments: Dict[str, str] = None) -> types.GetPromptResult:
+        """
+        Build prompt to verify single user-provided requirement implementation.
+        Expects: arguments = {"requirement_text": "..."}
+        """
+        prompt_lang = os.environ.get("prompt_lang", "en")
+        requirement_text = ""
+        if arguments and isinstance(arguments, dict):
+            requirement_text = arguments.get("requirement_text", "")
+
+        if prompt_lang == "vi":
+            prompt = PromptTemplates.get_single_requirement_verification_prompt_vi(requirement_text)
+        else:
+            prompt = PromptTemplates.get_single_requirement_verification_prompt(requirement_text)
+
+        messages = [
+            types.PromptMessage(
+                role="user",
+                content=types.TextContent(type="text", text=prompt),
+            )
+        ]
+        return types.GetPromptResult(
+            messages=messages,
+            description="Prompt to verify implementation of a single requirement.",
+        )
+    
     async def _handle_lgedv_check(self) -> types.GetPromptResult:
         import os
         prompt_lang = os.environ.get("prompt_lang", "en")
@@ -93,7 +125,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -139,7 +171,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -186,7 +218,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -232,7 +264,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -278,7 +310,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -302,6 +334,353 @@ class PromptHandler:
         logger.info("Custom check prompt completed")
         return result
     
+   
+    async def _handle_cim_static_check(self) -> types.GetPromptResult:
+        """Handle CIM Static Analysis (Coverity) result verification prompt"""
+        prompt_lang = os.environ.get("prompt_lang", "en")
+        if prompt_lang == "vi":
+            prompt = (
+                "Bạn là chuyên gia phân tích tĩnh C++/C với kinh nghiệm sâu về Coverity Static Analysis. "
+                "Hãy phân tích file code hiện tại cùng với các báo cáo vi phạm từ hệ thống CIM (Coverity).\n"
+                "Nếu chưa có file rule, hãy gọi fetch_static_analysis_rule từ MCP server để tải bộ quy tắc LGE Static Analysis.\n"
+                "Luôn sử dụng bộ quy tắc mới nhất vừa fetch để đối chiếu với kết quả CIM.\n"
+                "Hãy ghi rõ bộ rule nào đang dùng trong báo cáo.\n\n"
+                
+                "**NHIỆM VỤ CHÍNH:**\n"
+                "1. **KIỂM TRA TÍNH CHÍNH XÁC**: Xác minh xem các CID (Coverity Issue ID) được báo cáo có thực sự là lỗi hay không\n"
+                "2. **ĐỀ XUẤT GIẢI PHÁP**: Đưa ra code fix cụ thể cho mỗi lỗi thực sự\n"
+                "3. **ĐỐI CHIẾU RULE**: So sánh với bộ quy tắc LGE Static Analysis để xác thực\n\n"
+                
+                "**PHÂN TÍCH CID FORMAT:**\n"
+                "- CID [số]: [loại lỗi] - [mô tả chi tiết]\n"
+                "- Ví dụ: CID 6863827: Variable copied when it could be moved (COPY_INSTEAD_OF_MOVE)\n"
+                "- Ví dụ: CID 7257883: Unchecked return value (CHECKED_RETURN)\n"
+                "- Các loại phổ biến: CHECKED_RETURN, COPY_INSTEAD_OF_MOVE, NULL_RETURNS, RESOURCE_LEAK, TAINTED_DATA\n\n"
+                
+                "**LƯU Ý QUAN TRỌNG VỀ CID SELECTION:**\n"
+                "- **CHỈ PHÂN TÍCH CID CÓ MÔ TẢ CHI TIẾT**: Chỉ focus vào những CID có mô tả defect cụ thể\n"
+                "- **BỎ QUA CID 'SELECT ISSUE'**: Không phân tích những CID chỉ có [ \"select issue\" ] mà không có mô tả chi tiết\n"
+                "- **Ví dụ CID cần phân tích**: CID 6863827: Variable copied when it could be moved (COPY_INSTEAD_OF_MOVE) - detailed description here...\n"
+                "- **Ví dụ CID bỏ qua**: CID 6795225: [ \"select issue\" ]\n\n"
+                
+                "**YÊU CẦU PHÂN TÍCH:**\n"
+                "- Đọc kỹ từng CID CÓ MÔ TẢ CHI TIẾT và vị trí line number được báo\n"
+                "- Kiểm tra context xung quanh để hiểu flow execution\n"
+                "- Xác định: TRUE POSITIVE (lỗi thực) vs FALSE POSITIVE (báo nhầm)\n"
+                "- Đánh giá mức độ nghiêm trọng: Critical/High/Medium/Low/Info\n"
+                "- Kiểm tra các pattern: memory leaks, null pointer, buffer overflow, race conditions, resource leaks\n"      
+                "- Đối chiếu với bộ quy tắc LGE Static Analysis để xác thực độ chính xác\n"
+                "- **IGNORE tất cả CID chỉ có [ \"select issue\" ] mà không có mô tả defect cụ thể**\n\n"
+                
+                "**ĐỊNH DẠNG BÁO CÁO:**\n"
+                "Với mỗi CID CÓ MÔ TẢ CHI TIẾT:\n"
+                "## 🔍 CID [số]: [Tên lỗi]\n\n"
+                "**Vị trí:** Line [số] trong [tên hàm hoặc global scope]\n\n"
+                "**Loại phân tích:** [TRUE POSITIVE/FALSE POSITIVE]\n\n"
+                "**Mức độ nghiêm trọng:** [Critical/High/Medium/Low/Info]\n\n"
+                "**Mô tả lỗi:** [Giải thích chi tiết vấn đề Coverity phát hiện]\n\n"
+                "**Đối chiếu rule:** [So sánh với LGE Static Analysis rules]\n\n"
+                "**Code hiện tại:**\n"
+                "```cpp\n[paste exact code có lỗi với line numbers]\n```\n\n"
+                
+                "**Code đã sửa:** (chỉ cho TRUE POSITIVE)\n"
+                "```cpp\n[code đã fix hoàn chỉnh]\n```\n\n"
+                
+                "**Giải thích fix:** [Tại sao fix này đúng, an toàn và hiệu quả hơn]\n\n"              
+                "**Ghi chú:** [Context hoặc lưu ý đặc biệt, impact đến performance]\n\n"
+                "---\n\n"
+                
+                "**TỔNG KẾT CUỐI BÁO CÁO:**\n"
+                "- Tổng số CID CÓ MÔ TẢ CHI TIẾT phát hiện: [X]\n"
+                "- CID chỉ có [ \"select issue\" ] đã bỏ qua: [Y]\n"
+                "- TRUE POSITIVE (cần fix ngay): [Z]\n"
+                "- FALSE POSITIVE (có thể ignore): [W]\n"
+                "- Critical/High priority: [V] (ưu tiên cao nhất)\n"         
+                "- Phù hợp với LGE Static Analysis: [L] (đối chiếu với bộ rule)\n\n"
+                
+                "**KHUYẾN NGHỊ HÀNH ĐỘNG:**\n"
+                "1. Fix ngay các Critical/High severity issues có mô tả chi tiết\n"
+                "2. Review và plan cho Medium severity\n"
+                "3. Suppress FALSE POSITIVE với comment rõ ràng\n"
+                "4. Update coding practices để tránh tương lai\n"
+                "5. Có thể review lại những CID [ \"select issue\" ] nếu cần thiết\n\n"
+                
+                "**LƯU Ý QUAN TRỌNG:**\n"
+                "- **CHỈ PHÂN TÍCH CID CÓ MÔ TẢ DEFECT CỤ THỂ** - bỏ qua [ \"select issue\" ]\n"
+                "- Ưu tiên phân tích security và memory safety defects\n"
+                "- Với FALSE POSITIVE, giải thích rõ tại sao Coverity báo nhầm\n"
+                "- Đề xuất suppression comment nếu cần: // coverity[CID_NUMBER]\n"
+                "- Kiểm tra cross-reference giữa các CID liên quan\n"
+                "- Xem xét impact performance của fix\n"
+                "- Đảm bảo fix không gây side effects khác\n"
+                "- Luôn đối chiếu với bộ quy tắc LGE Static Analysis để đảm bảo consistency"
+            )
+        else:
+            prompt = (
+                "You are a C++/C static analysis expert with deep Coverity Static Analysis experience. "
+                "Please analyze the current code file along with CIM (Coverity) violation reports.\n"
+                "If no rule file available, call fetch_static_analysis_rule from MCP server to download LGE Static Analysis rules.\n"
+                "Always use the latest fetched rules to cross-reference with CIM results.\n"
+                "Please specify which rule set you are using in your report.\n\n"
+                
+                "**PRIMARY TASKS:**\n"
+                "1. **ACCURACY VERIFICATION**: Verify if reported CIDs (Coverity Issue IDs) are actual defects\n"
+                "2. **SOLUTION PROPOSAL**: Provide specific code fixes for each real defect\n"
+                "3. **RULE CROSS-REFERENCE**: Compare with LGE Static Analysis rules for validation\n\n"
+                
+                "**CID FORMAT ANALYSIS:**\n"
+                "- CID [number]: [defect type] - [detailed description]\n"
+                "- Example: CID 6863827: Variable copied when it could be moved (COPY_INSTEAD_OF_MOVE)\n"
+                "- Example: CID 7257883: Unchecked return value (CHECKED_RETURN)\n"
+                "- Common types: CHECKED_RETURN, COPY_INSTEAD_OF_MOVE, NULL_RETURNS, RESOURCE_LEAK, TAINTED_DATA\n\n"
+                
+                "**IMPORTANT NOTE ABOUT CID SELECTION:**\n"
+                "- **ANALYZE ONLY CIDs WITH DETAILED DESCRIPTIONS**: Focus only on CIDs with specific defect descriptions\n"
+                "- **IGNORE 'SELECT ISSUE' CIDs**: Skip CIDs that only have [ \"select issue\" ] without detailed description\n"
+                "- **Example CID to analyze**: CID 6863827: Variable copied when it could be moved (COPY_INSTEAD_OF_MOVE) - detailed description here...\n"
+                "- **Example CID to ignore**: CID 6795225: [ \"select issue\" ]\n\n"
+                
+                "**ANALYSIS REQUIREMENTS:**\n"
+                "- Read each CID WITH DETAILED DESCRIPTION and reported line number carefully\n"
+                "- Check surrounding context to understand execution flow\n"
+                "- Determine: TRUE POSITIVE (real defect) vs FALSE POSITIVE (false alarm)\n"
+                "- Assess severity: Critical/High/Medium/Low/Info\n"
+                "- Check patterns: memory leaks, null pointer, buffer overflow, race conditions, resource leaks\n"            
+                "- Cross-reference with LGE Static Analysis rules for validation\n"
+                "- **IGNORE all CIDs with only [ \"select issue\" ] and no specific defect description**\n\n"
+                
+                "**REPORT FORMAT:**\n"
+                "For each CID WITH DETAILED DESCRIPTION:\n"
+                "## 🔍 CID [number]: [Defect Name]\n\n"
+                "**Location:** Line [number] in [function name or global scope]\n\n"
+                "**Analysis Type:** [TRUE POSITIVE/FALSE POSITIVE]\n\n"
+                "**Severity:** [Critical/High/Medium/Low/Info]\n\n"
+                "**Defect Description:** [Detailed explanation of what Coverity detected]\n\n"
+                "**Rule Cross-Reference:** [Compare with LGE Static Analysis rules]\n\n"
+                "**Current Code:**\n"
+                "```cpp\n[paste exact defective code with line numbers]\n```\n\n"
+                
+                "**Fixed Code:** (only for TRUE POSITIVE)\n"
+                "```cpp\n[complete fixed code]\n```\n\n"
+                
+                "**Fix Explanation:** [Why this fix is correct, safe and more efficient]\n\n"            
+                "**Notes:** [Context or special considerations, performance impact]\n\n"
+                "---\n\n"
+                
+                "**FINAL SUMMARY:**\n"
+                "- Total CIDs WITH DETAILED DESCRIPTION detected: [X]\n"
+                "- CIDs with only [ \"select issue\" ] ignored: [Y]\n"
+                "- TRUE POSITIVE (needs immediate fix): [Z]\n"
+                "- FALSE POSITIVE (can be ignored): [W]\n"
+                "- Critical/High priority: [V] (highest priority)\n"                
+                "- LGE Static Analysis compliance: [L] (rule set cross-reference)\n\n"
+                
+                "**ACTION RECOMMENDATIONS:**\n"
+                "1. Fix Critical/High severity issues with detailed descriptions immediately\n"
+                "2. Review and plan for Medium severity\n"
+                "3. Suppress FALSE POSITIVE with clear comments\n"
+                "4. Update coding practices for future prevention\n"
+                "5. May review [ \"select issue\" ] CIDs separately if needed\n\n"
+                
+                "**IMPORTANT NOTES:**\n"
+                "- **ANALYZE ONLY CIDs WITH SPECIFIC DEFECT DESCRIPTIONS** - ignore [ \"select issue\" ]\n"
+                "- Prioritize security and memory safety defects\n"
+                "- For FALSE POSITIVE, explain clearly why Coverity reported incorrectly\n"
+                "- Suggest suppression comments if needed: // coverity[CID_NUMBER]\n"
+                "- Check cross-references between related CIDs\n"
+                "- Consider performance impact of fixes\n"
+                "- Ensure fixes don't cause other side effects\n"
+                "- Always cross-reference with LGE Static Analysis rules for consistency"
+            )
+        
+        messages = [
+            types.PromptMessage(
+                role="user",
+                content=types.TextContent(type="text", text=prompt),
+            )
+        ]
+        result = types.GetPromptResult(
+            messages=messages,
+            description="A prompt for CIM Static Analysis (Coverity) result verification with LGE rule cross-reference.",
+        )
+        logger.info("CIM Static Analysis check prompt")
+        return result
+    
+    
+    async def _handle_cim_misra_cpp_check(self) -> types.GetPromptResult:
+        """Handle CIM Static Analysis (Coverity) result verification prompt for MISRA C++ violations"""
+        import os
+        prompt_lang = os.environ.get("prompt_lang", "en")
+        if prompt_lang == "vi":
+            prompt = (
+                "Bạn là chuyên gia phân tích tĩnh C++/C với kinh nghiệm sâu về Coverity Static Analysis và MISRA C++ 2008. "
+                "Hãy phân tích file code hiện tại cùng với các báo cáo vi phạm MISRA C++ từ hệ thống CIM (Coverity).\n"
+                "Nếu chưa có file rule, hãy gọi fetch_misra_cpp_rule từ MCP server để tải bộ quy tắc MISRA C++ 2008.\n"
+                "Luôn sử dụng bộ quy tắc MISRA C++ mới nhất vừa fetch để đối chiếu với kết quả CIM.\n"
+                "Hãy ghi rõ bộ rule nào đang dùng trong báo cáo.\n\n"
+                
+                "**NHIỆM VỤ CHÍNH:**\n"
+                "1. **KIỂM TRA TÍNH CHÍNH XÁC**: Xác minh xem các CID (Coverity Issue ID) cho MISRA C++ có thực sự là vi phạm hay không\n"
+                "2. **ĐỀ XUẤT GIẢI PHÁP**: Đưa ra code fix cụ thể cho mỗi vi phạm MISRA C++ thực sự\n"
+                "3. **ĐỐI CHIẾU RULE**: So sánh với bộ quy tắc MISRA C++ 2008 để xác thực\n\n"
+                
+                "**PHÂN TÍCH CID FORMAT CHO MISRA C++:**\n"
+                "- CID [số]: MISRA C++-2008 [Category] (MISRA C++-2008 Rule [X-Y-Z])\n"
+                "- Ví dụ: CID 6237279: MISRA C++-2008 Basic Concepts (MISRA C++-2008 Rule 3-2-3)\n"
+                "- Ví dụ: CID 6244494: MISRA C++-2008 Basic Concepts (MISRA C++-2008 Rule 3-9-2)\n"
+                "- Các category phổ biến: Basic Concepts, Lexical Conventions, Declarations, Preprocessor Directives\n\n"
+                
+                "**LƯU Ý QUAN TRỌNG VỀ CID SELECTION:**\n"
+                "- **CHỈ PHÂN TÍCH CID CÓ MÔ TẢ CHI TIẾT**: Chỉ focus vào những CID có mô tả violation cụ thể\n"
+                "- **BỎ QUA CID 'SELECT ISSUE'**: Không phân tích những CID chỉ có [ \"select issue\" ] mà không có mô tả chi tiết\n"
+                "- **Ví dụ CID cần phân tích**: CID 6769436: (#1 of 1): MISRA C++-2008 Declarations (MISRA C++-2008 Rule 7-1-1) misra_cpp_2008_rule_7_1_1_violation: The variable strValZ has a non-const type...\n"
+                "- **Ví dụ CID bỏ qua**: CID 6795225:MISRA C++-2008 Declarations (MISRA C++-2008 Rule 7-1-1) [ \"select issue\" ]\n\n"
+                
+                "**YÊU CẦU PHÂN TÍCH:**\n"
+                "- Đọc kỹ từng CID MISRA C++ CÓ MÔ TẢ CHI TIẾT và vị trí line number được báo\n"
+                "- Kiểm tra context xung quanh để hiểu vi phạm rule cụ thể\n"
+                "- Xác định: TRUE POSITIVE (vi phạm thực) vs FALSE POSITIVE (báo nhầm)\n"
+                "- Đánh giá mức độ nghiêm trọng: Critical/High/Medium/Low/Info\n"
+                "- Tập trung vào compliance với MISRA C++ 2008 standard\n"      
+                "- Đối chiếu với bộ quy tắc MISRA C++ 2008 chính thức để xác thực\n"
+                "- **IGNORE tất cả CID chỉ có [ \"select issue\" ] mà không có mô tả violation cụ thể**\n\n"
+                
+                "**ĐỊNH DẠNG BÁO CÁO:**\n"
+                "Với mỗi CID MISRA C++ CÓ MÔ TẢ CHI TIẾT:\n"
+                "## 🔍 CID [số]: MISRA C++ Rule [X-Y-Z] Violation\n\n"
+                "**Vị trí:** Line [số] trong [tên hàm hoặc global scope]\n\n"
+                "**Rule vi phạm:** MISRA C++-2008 Rule [X-Y-Z] - [Mô tả rule từ standard]\n\n"
+                "**Loại phân tích:** [TRUE POSITIVE/FALSE POSITIVE]\n\n"
+                "**Mức độ nghiêm trọng:** [Critical/High/Medium/Low/Info]\n\n"
+                "**Mô tả vi phạm:** [Giải thích chi tiết vi phạm MISRA rule cụ thể]\n\n"
+                "**Đối chiếu MISRA rule:** [So sánh với MISRA C++ 2008 standard chính thức]\n\n"
+                "**Code hiện tại:**\n"
+                "```cpp\n[paste exact code vi phạm với line numbers]\n```\n\n"
+                
+                "**Code đã sửa:** (chỉ cho TRUE POSITIVE)\n"
+                "```cpp\n[code đã fix tuân thủ MISRA C++]\n```\n\n"
+                
+                "**Giải thích fix:** [Tại sao fix này tuân thủ MISRA C++ và an toàn hơn]\n\n"              
+                "**Ghi chú:** [Context đặc biệt, deviation có thể chấp nhận được]\n\n"
+                "---\n\n"
+                
+                "**TỔNG KẾT CUỐI BÁO CÁO:**\n"
+                "- Tổng số CID MISRA C++ CÓ MÔ TẢ CHI TIẾT phát hiện: [X]\n"
+                "- CID chỉ có [ \"select issue\" ] đã bỏ qua: [Y]\n"
+                "- TRUE POSITIVE (cần fix ngay): [Z]\n"
+                "- FALSE POSITIVE (có thể ignore): [W]\n"
+                "- Critical/High priority: [V] (ưu tiên cao nhất)\n"         
+                "- Tuân thủ MISRA C++ 2008: [M] (đối chiếu với standard)\n\n"
+                
+                "**KHUYẾN NGHỊ HÀNH ĐỘNG:**\n"
+                "1. Fix ngay các Critical/High severity MISRA violations có mô tả chi tiết\n"
+                "2. Document justified deviations với clear rationale\n"
+                "3. Suppress FALSE POSITIVE với MISRA deviation comments\n"
+                "4. Update coding guidelines để prevent future violations\n"
+                "5. Có thể review lại những CID [ \"select issue\" ] nếu cần thiết\n\n"
+                
+                "**LƯU Ý QUAN TRỌNG:**\n"
+                "- **CHỈ PHÂN TÍCH CID CÓ MÔ TẢ VIOLATION CỤ THỂ** - bỏ qua [ \"select issue\" ]\n"
+                "- Ưu tiên các MISRA rules liên quan đến safety và reliability\n"
+                "- Với FALSE POSITIVE, giải thích rõ tại sao rule không áp dụng\n"
+                "- Đề xuất MISRA deviation comments: /* MISRA C++ Rule X-Y-Z deviation: [reason] */\n"
+                "- Kiểm tra consistency với toàn bộ MISRA C++ compliance strategy\n"
+                "- Xem xét impact của fix đến overall code maintainability\n"
+                "- Đảm bảo fix không vi phạm rules khác\n"
+                "- Luôn đối chiếu với MISRA C++ 2008 standard chính thức"
+            )
+        else:
+            prompt = (
+                "You are a C++/C static analysis expert with deep Coverity Static Analysis and MISRA C++ 2008 experience. "
+                "Please analyze the current code file along with CIM (Coverity) MISRA C++ violation reports.\n"
+                "If no rule file available, call fetch_misra_cpp_rule from MCP server to download MISRA C++ 2008 rules.\n"
+                "Always use the latest fetched MISRA C++ rules to cross-reference with CIM results.\n"
+                "Please specify which rule set you are using in your report.\n\n"
+                
+                "**PRIMARY TASKS:**\n"
+                "1. **ACCURACY VERIFICATION**: Verify if reported CIDs (Coverity Issue IDs) for MISRA C++ are actual violations\n"
+                "2. **SOLUTION PROPOSAL**: Provide specific code fixes for each real MISRA C++ violation\n"
+                "3. **RULE CROSS-REFERENCE**: Compare with MISRA C++ 2008 rules for validation\n\n"
+                
+                "**CID FORMAT ANALYSIS FOR MISRA C++:**\n"
+                "- CID [number]: MISRA C++-2008 [Category] (MISRA C++-2008 Rule [X-Y-Z])\n"
+                "- Example: CID 6237279: MISRA C++-2008 Basic Concepts (MISRA C++-2008 Rule 3-2-3)\n"
+                "- Example: CID 6244494: MISRA C++-2008 Basic Concepts (MISRA C++-2008 Rule 3-9-2)\n"
+                "- Common categories: Basic Concepts, Lexical Conventions, Declarations, Preprocessor Directives\n\n"
+                
+                "**IMPORTANT NOTE ABOUT CID SELECTION:**\n"
+                "- **ANALYZE ONLY CIDs WITH DETAILED DESCRIPTIONS**: Focus only on CIDs with specific violation descriptions\n"
+                "- **IGNORE 'SELECT ISSUE' CIDs**: Skip CIDs that only have [ \"select issue\" ] without detailed description\n"
+                "- **Example CID to analyze**: CID 6769436: (#1 of 1): MISRA C++-2008 Declarations (MISRA C++-2008 Rule 7-1-1) misra_cpp_2008_rule_7_1_1_violation: The variable strValZ has a non-const type...\n"
+                "- **Example CID to ignore**: CID 6795225:MISRA C++-2008 Declarations (MISRA C++-2008 Rule 7-1-1) [ \"select issue\" ]\n\n"
+                
+                "**ANALYSIS REQUIREMENTS:**\n"
+                "- Read each MISRA C++ CID WITH DETAILED DESCRIPTION and reported line number carefully\n"
+                "- Check surrounding context to understand specific rule violation\n"
+                "- Determine: TRUE POSITIVE (real violation) vs FALSE POSITIVE (false alarm)\n"
+                "- Assess severity: Critical/High/Medium/Low/Info\n"
+                "- Focus on MISRA C++ 2008 standard compliance\n"            
+                "- Cross-reference with official MISRA C++ 2008 rules for validation\n"
+                "- **IGNORE all CIDs with only [ \"select issue\" ] and no specific violation description**\n\n"
+                
+                "**REPORT FORMAT:**\n"
+                "For each MISRA C++ CID WITH DETAILED DESCRIPTION:\n"
+                "## 🔍 CID [number]: MISRA C++ Rule [X-Y-Z] Violation\n\n"
+                "**Location:** Line [number] in [function name or global scope]\n\n"
+                "**Rule Violated:** MISRA C++-2008 Rule [X-Y-Z] - [Rule description from standard]\n\n"
+                "**Analysis Type:** [TRUE POSITIVE/FALSE POSITIVE]\n\n"
+                "**Severity:** [Critical/High/Medium/Low/Info]\n\n"
+                "**Violation Description:** [Detailed explanation of specific MISRA rule violation]\n\n"
+                "**MISRA Rule Cross-Reference:** [Compare with official MISRA C++ 2008 standard]\n\n"
+                "**Current Code:**\n"
+                "```cpp\n[paste exact violating code with line numbers]\n```\n\n"
+                
+                "**Fixed Code:** (only for TRUE POSITIVE)\n"
+                "```cpp\n[MISRA C++ compliant fixed code]\n```\n\n"
+                
+                "**Fix Explanation:** [Why this fix complies with MISRA C++ and is safer]\n\n"            
+                "**Notes:** [Special context, acceptable deviations]\n\n"
+                "---\n\n"
+                
+                "**FINAL SUMMARY:**\n"
+                "- Total MISRA C++ CIDs WITH DETAILED DESCRIPTION detected: [X]\n"
+                "- CIDs with only [ \"select issue\" ] ignored: [Y]\n"
+                "- TRUE POSITIVE (needs immediate fix): [Z]\n"
+                "- FALSE POSITIVE (can be ignored): [W]\n"
+                "- Critical/High priority: [V] (highest priority)\n"                
+                "- MISRA C++ 2008 compliance: [M] (standard cross-reference)\n\n"
+                
+                "**ACTION RECOMMENDATIONS:**\n"
+                "1. Fix Critical/High severity MISRA violations with detailed descriptions immediately\n"
+                "2. Document justified deviations with clear rationale\n"
+                "3. Suppress FALSE POSITIVE with MISRA deviation comments\n"
+                "4. Update coding guidelines to prevent future violations\n"
+                "5. May review [ \"select issue\" ] CIDs separately if needed\n\n"
+                
+                "**IMPORTANT NOTES:**\n"
+                "- **ANALYZE ONLY CIDs WITH SPECIFIC VIOLATION DESCRIPTIONS** - ignore [ \"select issue\" ]\n"
+                "- Prioritize MISRA rules related to safety and reliability\n"
+                "- For FALSE POSITIVE, explain clearly why rule doesn't apply\n"
+                "- Suggest MISRA deviation comments: /* MISRA C++ Rule X-Y-Z deviation: [reason] */\n"
+                "- Check consistency with overall MISRA C++ compliance strategy\n"
+                "- Consider impact of fixes on overall code maintainability\n"
+                "- Ensure fixes don't violate other rules\n"
+                "- Always cross-reference with official MISRA C++ 2008 standard"
+            )
+        
+        messages = [
+            types.PromptMessage(
+                role="user",
+                content=types.TextContent(type="text", text=prompt),
+            )
+        ]
+        result = types.GetPromptResult(
+            messages=messages,
+            description="A prompt for CIM Static Analysis (Coverity) MISRA C++ result verification with MISRA C++ 2008 rule cross-reference.",
+        )
+        logger.info("CIM MISRA C++ check prompt completed")
+        return result
+
     async def _handle_autosar_check(self) -> types.GetPromptResult:
         """Handle AUTOSAR C++ 14 code checking prompt"""
         import os
@@ -324,7 +703,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```cpp\n[code lỗi]\n```\n"
@@ -370,7 +749,7 @@ class PromptHandler:
                 "Với mỗi lỗi:\n"
                 "## 🚨 Vấn đề [#]: [Mô tả ngắn]\n\n"
                 "**Rule vi phạm:** [SỐ HIỆU] - [Mô tả rule]\n\n"
-                "**Vị trí:** [tên hàm hoặc global/unknown]\n\n"
+                "**Vị trí:** [tên file, tên hàm hoặc global/unknown]\n\n"
                 "**Mức độ:** [Critical/High/Medium/Low]\n\n"
                 "**Code hiện tại:**\n"
                 "```c\n[code lỗi]\n```\n"
