@@ -3,6 +3,7 @@ Tool handlers for MCP server operations
 Xử lý các MCP tools (fetch rules, analyze files, etc.)
 """
 import os
+import glob
 from typing import List, Union, Dict
 from mcp import types
 from mcp.types import TextContent
@@ -22,6 +23,7 @@ from lgedv.modules.persistent_storage import PersistentTracker
 from lgedv.handlers.requirement_handler import handle_requirement_analysis
 from lgedv.handlers.interface_handler import get_interface
 
+
 import pprint
 from datetime import datetime
 
@@ -1365,19 +1367,22 @@ class ToolHandler:
 
     async def _handle_report_rule_violation(self, arguments: dict):
         """
-        Quét tất cả file .md trong report_dir, tổng hợp tất cả rule violations vào 1 file rule_violation.html
+        Quét tất cả file .md trong report_dir, tổng hợp tất cả rule violations vào cả file HTML và Excel
         Luôn luôn xóa file báo cáo cũ và tạo mới để đảm bảo tính cập nhật
         """
         report_dir = os.environ.get("report_dir", "./report")
         
-        # 🔥 BƯỚC 1: Xóa file HTML báo cáo cũ nếu tồn tại
-        output_path = os.path.join(report_dir, "rule_violation.html")  # Đổi thành số nhiều để nhất quán
-        if os.path.exists(output_path):
-            try:
-                os.remove(output_path)
-                logger.info("🗑️  Deleted existing rule violations report: %s", output_path)
-            except Exception as e:
-                logger.warning("Failed to delete existing rule violations report: %s", e)
+        # 🔥 BƯỚC 1: Xóa cả file HTML và Excel báo cáo cũ nếu tồn tại
+        html_output_path = os.path.join(report_dir, "rule_violation.html")
+        excel_output_path = os.path.join(report_dir, "rule_violation.xlsx")
+        
+        for output_path in [html_output_path, excel_output_path]:
+            if os.path.exists(output_path):
+                try:
+                    os.remove(output_path)
+                    logger.info("🗑️  Deleted existing rule violations report: %s", output_path)
+                except Exception as e:
+                    logger.warning("Failed to delete existing rule violations report: %s", e)
         
         # 🔥 BƯỚC 2: Quét và phân tích lại TẤT CẢ file .md từ đầu
         all_violations = []
@@ -1406,18 +1411,34 @@ class ToolHandler:
                     logger.error("❌ Error processing %s: %s", fname, e)
                     continue
         
-        # 🔥 BƯỚC 3: Tạo báo cáo HTML mới hoàn toàn
+        # 🔥 BƯỚC 3: Tạo báo cáo HTML và Excel mới hoàn toàn
         if all_violations:
-            report_rule.write_consolidated_html_table(all_violations, output_path, processed_files)
+            # Tạo báo cáo HTML
+            report_rule.write_consolidated_html_table(all_violations, html_output_path, processed_files)
+            
+            # Tạo báo cáo Excel (cần cài pandas và openpyxl)
+            try:
+                report_rule.write_consolidated_excel_report(all_violations, excel_output_path, processed_files)
+                excel_status = f"✅ Excel report: {excel_output_path}"
+            except ImportError as e:
+                excel_status = f"⚠️  Excel report skipped (missing dependencies: {e})"
+            except Exception as e:
+                excel_status = f"❌ Excel report failed: {e}"
+            
             return [types.TextContent(
                 type="text", 
-                text=f"🔄 Re-generated fresh rule violations report with {len(all_violations)} violations from {len(processed_files)} files: {output_path}\n"
+                text=f"🔄 Re-generated fresh rule violations reports with {len(all_violations)} violations from {len(processed_files)} files:\n"
+                    f"✅ HTML report: {html_output_path}\n"
+                    f"{excel_status}\n"
                     f"📊 Processed files: {', '.join(processed_files)}\n"
-                    f"🗑️  Previous report deleted and regenerated from scratch"
+                    f"🗑️  Previous reports deleted and regenerated from scratch"
             )]
         else:
-            # Tạo file HTML trống để báo hiệu không có rule violation
-            with open(output_path, 'w', encoding='utf-8') as f:
+            # Tạo file HTML và Excel trống để báo hiệu không có rule violation
+            from datetime import datetime
+            
+            # HTML trống
+            with open(html_output_path, 'w', encoding='utf-8') as f:
                 f.write("""<!DOCTYPE html>
     <html><head><meta charset="utf-8"><title>Rule Violations Report - No Issues Found</title></head>
     <body>
@@ -1428,220 +1449,387 @@ class ToolHandler:
     </body></html>""".format(len(processed_files), 
                             datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
             
+            # Excel trống
+            try:
+                from openpyxl import Workbook
+                wb = Workbook()
+                ws = wb.active
+                ws.title = "Rule Violations Report"
+                ws['A1'] = "Rule Violations Analysis Report"
+                ws['A2'] = "Status: No rule violations detected"
+                ws['A3'] = f"Files analyzed: {len(processed_files)}"
+                ws['A4'] = f"Generated on: {datetime.now().strftime('%Y-%m-%d %H:%M:%S')}"
+                wb.save(excel_output_path)
+                excel_status = f"✅ Clean Excel report: {excel_output_path}"
+            except Exception as e:
+                excel_status = f"⚠️  Excel report creation failed: {e}"
+            
             return [types.TextContent(
                 type="text", 
-                text=f"✅ No rule violations found in {len(processed_files)} processed files. Clean report generated: {output_path}"
+                text=f"✅ No rule violations found in {len(processed_files)} processed files.\n"
+                    f"✅ Clean HTML report: {html_output_path}\n"
+                    f"{excel_status}"
             )]
 
     
     async def _handle_report_mem_leak(self, arguments: dict):
         """
-        Quét tất cả file .md trong report_dir, tổng hợp tất cả memory leaks vào 1 file memory_leak.html
+        Quét tất cả file .md trong report_dir, tổng hợp tất cả memory leaks vào cả file HTML và Excel
         Luôn luôn xóa file báo cáo cũ và tạo mới để đảm bảo tính cập nhật
         """
         report_dir = os.environ.get("report_dir", "./report")
         
-        # 🔥 BƯỚC 1: Xóa file HTML báo cáo cũ nếu tồn tại
-        output_path = os.path.join(report_dir, "memory_leak.html")  # KHÔNG CÓ 'S'
-        if os.path.exists(output_path):
-            try:
+        # 🔥 BƯỚC 1: Xóa cả file HTML và Excel báo cáo cũ nếu tồn tại
+        html_output_path = os.path.join(report_dir, "mem_leak.html")
+        excel_output_path = os.path.join(report_dir, "mem_leak.xlsx")
+        
+        for output_path in [html_output_path, excel_output_path]:
+            if os.path.exists(output_path):
                 os.remove(output_path)
-                logger.info("🗑️  Deleted existing memory leak report: %s", output_path)
-            except Exception as e:
-                logger.warning("Failed to delete existing memory leak report: %s", e)
+                logger.info(f"Removed existing report: {output_path}")
         
         # 🔥 BƯỚC 2: Quét và phân tích lại TẤT CẢ file .md từ đầu
         all_leaks = []
-        processed_files = []
+        source_files = []
         
-        logger.info("🔍 Re-analyzing ALL .md files for memory leaks...")
+        if not os.path.exists(report_dir):
+            return [types.TextContent(type="text", text=f"❌ Report directory not found: {report_dir}")]
         
-        for fname in os.listdir(report_dir):
-            if fname.endswith(".md"):
-                input_path = os.path.join(report_dir, fname)
-                try:
-                    with open(input_path, 'r', encoding='utf-8') as f:
-                        md_text = f.read()
-                    logger.info("Processing memory leaks from: %s", input_path)
-                    leaks = report_leak.extract_violations(md_text)  # DÙNG report_leak
-                    if leaks:
-                        for leak in leaks:
-                            leak['source_file'] = fname
-                        all_leaks.extend(leaks)
-                        processed_files.append(fname)
-                        logger.info("✅ Found %d memory leaks in %s", len(leaks), fname)
-                    else:
-                        logger.info("ℹ️  No memory leaks found in %s", fname)
-                except Exception as e:
-                    logger.error("❌ Error processing %s: %s", fname, e)
+        # Tìm tất cả file .md có chứa "MEMORY LEAK"
+        md_files = glob.glob(os.path.join(report_dir, "*.md"))
+        if not md_files:
+            return [types.TextContent(type="text", text=f"❌ No .md files found in {report_dir}")]
+        
+        logger.info(f"Found {len(md_files)} .md files in {report_dir}")
+        
+        # Import hàm extract_leaks từ report_leak.py
+        from lgedv.modules.report_leak import extract_violations
+        
+        for md_file in md_files:
+            try:
+                with open(md_file, 'r', encoding='utf-8') as f:
+                    md_content = f.read()
+                
+                # Chỉ xử lý file có chứa "MEMORY LEAK"
+                if "MEMORY LEAK" not in md_content:
+                    logger.info(f"Skipping {md_file} - no memory leak content")
                     continue
+                
+                leaks = extract_violations(md_content)
+                if leaks:
+                    logger.info(f"Found {len(leaks)} memory leaks in {md_file}")
+                    source_files.append(os.path.basename(md_file))
+                    
+                    # Thêm source_file vào mỗi leak để track origin
+                    for leak in leaks:
+                        leak['source_file'] = os.path.basename(md_file)
+                        all_leaks.append(leak)
+                else:
+                    logger.info(f"No memory leaks found in {md_file}")
+                    
+            except Exception as e:
+                logger.error(f"Error processing {md_file}: {e}")
+                continue
         
-        # 🔥 BƯỚC 3: Tạo báo cáo HTML mới hoàn toàn
-        if all_leaks:
-            report_leak.write_consolidated_html_table(all_leaks, output_path, processed_files)
-            return [types.TextContent(
-                type="text", 
-                text=f"🔄 Re-generated fresh memory leak report with {len(all_leaks)} leaks from {len(processed_files)} files: {output_path}\n"
-                    f"📊 Processed files: {', '.join(processed_files)}\n"
-                    f"🗑️  Previous report deleted and regenerated from scratch"
-            )]
-        else:
-            # Tạo file HTML trống để báo hiệu không có memory leak
-            with open(output_path, 'w', encoding='utf-8') as f:
-                f.write("""<!DOCTYPE html>
-    <html><head><meta charset="utf-8"><title>Memory Leak Report - No Issues Found</title></head>
-    <body>
-    <h1>Memory Leak Analysis Report</h1>
-    <p><strong>Status:</strong> ✅ No memory leaks detected</p>
-    <p><strong>Files analyzed:</strong> {}</p>
-    <p><strong>Generated on:</strong> {}</p>
-    </body></html>""".format(len(processed_files), 
-                            datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
+        if not all_leaks:
+            return [types.TextContent(type="text", text=f"❌ No memory leaks found in any .md files in {report_dir}")]
+        
+        # 🔥 BƯỚC 3: Tạo cả HTML và Excel reports
+        from lgedv.modules.report_leak import write_consolidated_html_table, write_consolidated_excel_report
+        
+        try:
+            # Tạo HTML report
+            write_consolidated_html_table(all_leaks, html_output_path, source_files)
+            logger.info(f"HTML report created: {html_output_path}")
             
-            return [types.TextContent(
-                type="text", 
-                text=f"✅ No memory leaks found in {len(processed_files)} processed files. Clean report generated: {output_path}"
-            )]
+            # Tạo Excel report
+            write_consolidated_excel_report(all_leaks, excel_output_path, source_files)
+            logger.info(f"Excel report created: {excel_output_path}")
+            
+            # Thống kê chi tiết
+            total_leaks = len(all_leaks)
+            leak_by_severity = {}
+            leak_by_type = {}
+            
+            for leak in all_leaks:
+                severity = leak.get('severity', 'unknown')
+                leak_type = leak.get('type', 'unknown')
+                
+                leak_by_severity[severity] = leak_by_severity.get(severity, 0) + 1
+                leak_by_type[leak_type] = leak_by_type.get(leak_type, 0) + 1
+            
+            # Tạo response message
+            response_text = f"✅ **Memory Leak Report Generated Successfully**\n\n"
+            response_text += f"📊 **Summary:**\n"
+            response_text += f"- **Source Files Processed**: {len(source_files)}\n"
+            response_text += f"- **Total Memory Leaks**: {total_leaks}\n\n"
+            
+            if leak_by_severity:
+                response_text += f"📈 **By Severity:**\n"
+                for severity, count in sorted(leak_by_severity.items()):
+                    emoji = {"critical": "🔴", "high": "🟠", "medium": "🟡", "low": "🟢"}.get(severity, "⚪")
+                    response_text += f"- {emoji} {severity.title()}: {count}\n"
+                response_text += "\n"
+            
+            if leak_by_type:
+                response_text += f"🔍 **By Type:**\n"
+                for leak_type, count in sorted(leak_by_type.items()):
+                    response_text += f"- {leak_type}: {count}\n"
+                response_text += "\n"
+            
+            response_text += f"📁 **Output Files:**\n"
+            response_text += f"- **HTML Report**: `{html_output_path}`\n"
+            response_text += f"- **Excel Report**: `{excel_output_path}`\n\n"
+            
+            response_text += f"📝 **Source Files:**\n"
+            for i, source_file in enumerate(source_files, 1):
+                response_text += f"{i}. {source_file}\n"
+            
+            return [types.TextContent(type="text", text=response_text)]
+            
+        except Exception as e:
+            logger.error(f"Error generating memory leak reports: {e}")
+            return [types.TextContent(type="text", text=f"❌ Error generating reports: {str(e)}")]
 
 
     async def _handle_report_race_condition(self, arguments: dict):
         """
-        Quét tất cả file .md trong report_dir, tổng hợp tất cả race conditions vào 1 file race_condition.html
+        Quét tất cả file .md trong report_dir, tổng hợp tất cả race conditions vào cả file HTML và Excel
         Luôn luôn xóa file báo cáo cũ và tạo mới để đảm bảo tính cập nhật
         """
         report_dir = os.environ.get("report_dir", "./report")
         
-        # 🔥 BƯỚC 1: Xóa file HTML báo cáo cũ nếu tồn tại
-        output_path = os.path.join(report_dir, "race_condition.html")  # Đảm bảo tên file nhất quán
-        if os.path.exists(output_path):
-            try:
+        # 🔥 BƯỚC 1: Xóa cả file HTML và Excel báo cáo cũ nếu tồn tại
+        html_output_path = os.path.join(report_dir, "race_condition.html")
+        excel_output_path = os.path.join(report_dir, "race_condition.xlsx")
+        
+        for output_path in [html_output_path, excel_output_path]:
+            if os.path.exists(output_path):
                 os.remove(output_path)
-                logger.info("🗑️  Deleted existing race condition report: %s", output_path)
-            except Exception as e:
-                logger.warning("Failed to delete existing race condition report: %s", e)
+                logger.info(f"Removed existing report: {output_path}")
         
         # 🔥 BƯỚC 2: Quét và phân tích lại TẤT CẢ file .md từ đầu
         all_races = []
-        processed_files = []
+        source_files = []
         
-        logger.info("🔍 Re-analyzing ALL .md files for race conditions...")
+        if not os.path.exists(report_dir):
+            return [types.TextContent(type="text", text=f"❌ Report directory not found: {report_dir}")]
         
-        for fname in os.listdir(report_dir):
-            if fname.endswith(".md"):
-                input_path = os.path.join(report_dir, fname)
-                try:
-                    with open(input_path, 'r', encoding='utf-8') as f:
-                        md_text = f.read()
-                    logger.info("Processing race conditions from: %s", input_path)
-                    races = report_race.extract_races(md_text)
-                    if races:
-                        for race in races:
-                            race['source_file'] = fname
-                        all_races.extend(races)
-                        processed_files.append(fname)
-                        logger.info("✅ Found %d race conditions in %s", len(races), fname)
-                    else:
-                        logger.info("ℹ️  No race conditions found in %s", fname)
-                except Exception as e:
-                    logger.error("❌ Error processing %s: %s", fname, e)
+        # Tìm tất cả file .md có chứa "RACE CONDITION"
+        md_files = glob.glob(os.path.join(report_dir, "*.md"))
+        if not md_files:
+            return [types.TextContent(type="text", text=f"❌ No .md files found in {report_dir}")]
+        
+        logger.info(f"Found {len(md_files)} .md files in {report_dir}")
+        
+        # Import hàm extract_races từ report_race.py
+        from lgedv.modules.report_race import extract_races
+        
+        for md_file in md_files:
+            try:
+                with open(md_file, 'r', encoding='utf-8') as f:
+                    md_content = f.read()
+                
+                # Chỉ xử lý file có chứa "RACE CONDITION"
+                if "RACE CONDITION" not in md_content:
+                    logger.info(f"Skipping {md_file} - no race condition content")
                     continue
+                
+                races = extract_races(md_content)
+                if races:
+                    logger.info(f"Found {len(races)} race conditions in {md_file}")
+                    source_files.append(os.path.basename(md_file))
+                    
+                    # Thêm source_file vào mỗi race để track origin
+                    for race in races:
+                        race['source_file'] = os.path.basename(md_file)
+                        all_races.append(race)
+                else:
+                    logger.info(f"No race conditions found in {md_file}")
+                    
+            except Exception as e:
+                logger.error(f"Error processing {md_file}: {e}")
+                continue
         
-        # 🔥 BƯỚC 3: Tạo báo cáo HTML mới hoàn toàn
-        if all_races:
-            report_race.write_consolidated_html_table(all_races, output_path, processed_files)
-            return [types.TextContent(
-                type="text", 
-                text=f"🔄 Re-generated fresh race condition report with {len(all_races)} races from {len(processed_files)} files: {output_path}\n"
-                    f"📊 Processed files: {', '.join(processed_files)}\n"
-                    f"🗑️  Previous report deleted and regenerated from scratch"
-            )]
-        else:
-            # Tạo file HTML trống để báo hiệu không có race condition
-            with open(output_path, 'w', encoding='utf-8') as f:
-                f.write("""<!DOCTYPE html>
-    <html><head><meta charset="utf-8"><title>Race Condition Report - No Issues Found</title></head>
-    <body>
-    <h1>Race Condition Analysis Report</h1>
-    <p><strong>Status:</strong> ✅ No race conditions detected</p>
-    <p><strong>Files analyzed:</strong> {}</p>
-    <p><strong>Generated on:</strong> {}</p>
-    </body></html>""".format(len(processed_files), 
-                            datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
+        if not all_races:
+            return [types.TextContent(type="text", text=f"❌ No race conditions found in any .md files in {report_dir}")]
+        
+        # 🔥 BƯỚC 3: Tạo cả HTML và Excel reports
+        from lgedv.modules.report_race import write_consolidated_html_table, write_consolidated_excel_report
+        
+        try:
+            # Tạo HTML report
+            write_consolidated_html_table(all_races, html_output_path, source_files)
+            logger.info(f"HTML report created: {html_output_path}")
             
-            return [types.TextContent(
-                type="text", 
-                text=f"✅ No race conditions found in {len(processed_files)} processed files. Clean report generated: {output_path}"
-            )]
+            # Tạo Excel report
+            write_consolidated_excel_report(all_races, excel_output_path, source_files)
+            logger.info(f"Excel report created: {excel_output_path}")
+            
+            # Thống kê chi tiết
+            total_races = len(all_races)
+            race_by_severity = {}
+            race_by_type = {}
+            
+            for race in all_races:
+                severity = race.get('Severity', 'unknown')
+                race_type = race.get('Type', 'unknown')
+                
+                race_by_severity[severity] = race_by_severity.get(severity, 0) + 1
+                race_by_type[race_type] = race_by_type.get(race_type, 0) + 1
+            
+            # Tạo response message
+            response_text = f"✅ **Race Condition Report Generated Successfully**\n\n"
+            response_text += f"📊 **Summary:**\n"
+            response_text += f"- **Source Files Processed**: {len(source_files)}\n"
+            response_text += f"- **Total Race Conditions**: {total_races}\n\n"
+            
+            if race_by_severity:
+                response_text += f"📈 **By Severity:**\n"
+                for severity, count in sorted(race_by_severity.items()):
+                    emoji = {"Critical": "🔴", "High": "🟠", "Medium": "🟡", "Low": "🟢"}.get(severity, "⚪")
+                    response_text += f"- {emoji} {severity}: {count}\n"
+                response_text += "\n"
+            
+            if race_by_type:
+                response_text += f"🔍 **By Type:**\n"
+                for race_type, count in sorted(race_by_type.items()):
+                    response_text += f"- {race_type}: {count}\n"
+                response_text += "\n"
+            
+            response_text += f"📁 **Output Files:**\n"
+            response_text += f"- **HTML Report**: `{html_output_path}`\n"
+            response_text += f"- **Excel Report**: `{excel_output_path}`\n\n"
+            
+            response_text += f"📝 **Source Files:**\n"
+            for i, source_file in enumerate(source_files, 1):
+                response_text += f"{i}. {source_file}\n"
+            
+            return [types.TextContent(type="text", text=response_text)]
+            
+        except Exception as e:
+            logger.error(f"Error generating race condition reports: {e}")
+            return [types.TextContent(type="text", text=f"❌ Error generating reports: {str(e)}")]
 
 
     async def _handle_report_resource_leak(self, arguments: dict):
         """
-        Quét tất cả file .md trong report_dir, tổng hợp tất cả resource leaks vào 1 file resource_leaks.html
+        Quét tất cả file .md trong report_dir, tổng hợp tất cả resource leaks vào cả file HTML và Excel
         Luôn luôn xóa file báo cáo cũ và tạo mới để đảm bảo tính cập nhật
         """
         report_dir = os.environ.get("report_dir", "./report")
         
-        # 🔥 BƯỚC 1: Xóa file HTML báo cáo cũ nếu tồn tại
-        output_path = os.path.join(report_dir, "resource_leak.html")  # Số nhiều cho nhất quán
-        if os.path.exists(output_path):
-            try:
+        # 🔥 BƯỚC 1: Xóa cả file HTML và Excel báo cáo cũ nếu tồn tại
+        html_output_path = os.path.join(report_dir, "resource_leak.html")
+        excel_output_path = os.path.join(report_dir, "resource_leak.xlsx")
+        
+        for output_path in [html_output_path, excel_output_path]:
+            if os.path.exists(output_path):
                 os.remove(output_path)
-                logger.info("🗑️  Deleted existing resource leak report: %s", output_path)
-            except Exception as e:
-                logger.warning("Failed to delete existing resource leak report: %s", e)
+                logger.info(f"Removed existing report: {output_path}")
         
         # 🔥 BƯỚC 2: Quét và phân tích lại TẤT CẢ file .md từ đầu
         all_leaks = []
-        processed_files = []
+        source_files = []
         
-        logger.info("🔍 Re-analyzing ALL .md files for resource leaks...")
+        if not os.path.exists(report_dir):
+            return [types.TextContent(type="text", text=f"❌ Report directory not found: {report_dir}")]
         
-        for fname in os.listdir(report_dir):
-            if fname.endswith(".md"):
-                input_path = os.path.join(report_dir, fname)
-                try:
-                    with open(input_path, 'r', encoding='utf-8') as f:
-                        md_text = f.read()
-                    logger.info("Processing resource leaks from: %s", input_path)
-                    leaks = report_resource.extract_violations(md_text)
-                    if leaks:
-                        for leak in leaks:
-                            leak['source_file'] = fname
-                        all_leaks.extend(leaks)
-                        processed_files.append(fname)
-                        logger.info("✅ Found %d resource leaks in %s", len(leaks), fname)
-                    else:
-                        logger.info("ℹ️  No resource leaks found in %s", fname)
-                except Exception as e:
-                    logger.error("❌ Error processing %s: %s", fname, e)
+        # Tìm tất cả file .md có chứa "RESOURCE LEAK"
+        md_files = glob.glob(os.path.join(report_dir, "*.md"))
+        if not md_files:
+            return [types.TextContent(type="text", text=f"❌ No .md files found in {report_dir}")]
+        
+        logger.info(f"Found {len(md_files)} .md files in {report_dir}")
+        
+        # Import hàm extract_violations từ report_resource.py
+        from lgedv.modules.report_resource import extract_violations
+        
+        for md_file in md_files:
+            try:
+                with open(md_file, 'r', encoding='utf-8') as f:
+                    md_content = f.read()
+                
+                # Chỉ xử lý file có chứa "RESOURCE LEAK"
+                if "RESOURCE LEAK" not in md_content:
+                    logger.info(f"Skipping {md_file} - no resource leak content")
                     continue
+                
+                leaks = extract_violations(md_content)
+                if leaks:
+                    logger.info(f"Found {len(leaks)} resource leaks in {md_file}")
+                    source_files.append(os.path.basename(md_file))
+                    
+                    # Thêm source_file vào mỗi leak để track origin
+                    for leak in leaks:
+                        leak['source_file'] = os.path.basename(md_file)
+                        all_leaks.append(leak)
+                else:
+                    logger.info(f"No resource leaks found in {md_file}")
+                    
+            except Exception as e:
+                logger.error(f"Error processing {md_file}: {e}")
+                continue
         
-        # 🔥 BƯỚC 3: Tạo báo cáo HTML mới hoàn toàn
-        if all_leaks:
-            report_resource.write_consolidated_html_table(all_leaks, output_path, processed_files)
-            return [types.TextContent(
-                type="text", 
-                text=f"🔄 Re-generated fresh resource leak report with {len(all_leaks)} leaks from {len(processed_files)} files: {output_path}\n"
-                    f"📊 Processed files: {', '.join(processed_files)}\n"
-                    f"🗑️  Previous report deleted and regenerated from scratch"
-            )]
-        else:
-            # Tạo file HTML trống để báo hiệu không có resource leak
-            with open(output_path, 'w', encoding='utf-8') as f:
-                f.write("""<!DOCTYPE html>
-    <html><head><meta charset="utf-8"><title>Resource Leak Report - No Issues Found</title></head>
-    <body>
-    <h1>Resource Leak Analysis Report</h1>
-    <p><strong>Status:</strong> ✅ No resource leaks detected</p>
-    <p><strong>Files analyzed:</strong> {}</p>
-    <p><strong>Generated on:</strong> {}</p>
-    </body></html>""".format(len(processed_files), 
-                            datetime.now().strftime("%Y-%m-%d %H:%M:%S")))
+        if not all_leaks:
+            return [types.TextContent(type="text", text=f"❌ No resource leaks found in any .md files in {report_dir}")]
+        
+        # 🔥 BƯỚC 3: Tạo cả HTML và Excel reports
+        from lgedv.modules.report_resource import write_consolidated_html_table, write_consolidated_excel_report
+        
+        try:
+            # Tạo HTML report
+            write_consolidated_html_table(all_leaks, html_output_path, source_files)
+            logger.info(f"HTML report created: {html_output_path}")
             
-            return [types.TextContent(
-                type="text", 
-                text=f"✅ No resource leaks found in {len(processed_files)} processed files. Clean report generated: {output_path}"
-            )]
+            # Tạo Excel report
+            write_consolidated_excel_report(all_leaks, excel_output_path, source_files)
+            logger.info(f"Excel report created: {excel_output_path}")
+            
+            # Thống kê chi tiết
+            total_leaks = len(all_leaks)
+            leak_by_severity = {}
+            leak_by_type = {}
+            
+            for leak in all_leaks:
+                severity = leak.get('Severity', 'unknown')
+                leak_type = leak.get('Type', 'unknown')
+                
+                leak_by_severity[severity] = leak_by_severity.get(severity, 0) + 1
+                leak_by_type[leak_type] = leak_by_type.get(leak_type, 0) + 1
+            
+            # Tạo response message
+            response_text = f"✅ **Resource Leak Report Generated Successfully**\n\n"
+            response_text += f"📊 **Summary:**\n"
+            response_text += f"- **Source Files Processed**: {len(source_files)}\n"
+            response_text += f"- **Total Resource Leaks**: {total_leaks}\n\n"
+            
+            if leak_by_severity:
+                response_text += f"📈 **By Severity:**\n"
+                for severity, count in sorted(leak_by_severity.items()):
+                    emoji = {"Critical": "🔴", "High": "🟠", "Medium": "🟡", "Low": "🟢"}.get(severity, "⚪")
+                    response_text += f"- {emoji} {severity}: {count}\n"
+                response_text += "\n"
+            
+            if leak_by_type:
+                response_text += f"🔍 **By Type:**\n"
+                for leak_type, count in sorted(leak_by_type.items()):
+                    response_text += f"- {leak_type}: {count}\n"
+                response_text += "\n"
+            
+            response_text += f"📁 **Output Files:**\n"
+            response_text += f"- **HTML Report**: `{html_output_path}`\n"
+            response_text += f"- **Excel Report**: `{excel_output_path}`\n\n"
+            
+            response_text += f"📝 **Source Files:**\n"
+            for i, source_file in enumerate(source_files, 1):
+                response_text += f"{i}. {source_file}\n"
+            
+            return [types.TextContent(type="text", text=response_text)]
+            
+        except Exception as e:
+            logger.error(f"Error generating resource leak reports: {e}")
+            return [types.TextContent(type="text", text=f"❌ Error generating reports: {str(e)}")]
         
     async def _handle_analyze_requirement(self, arguments: dict) -> List[types.TextContent]:
         """Handle analyze_requirement tool"""
