@@ -76,6 +76,13 @@ async def fetch_lgedv_rule(url: str = None) -> List[Union[
     fetcher = RuleFetcher()
     return await fetcher.fetch_rule("lgedv", url)
 
+async def fetch_static_analysis_rule(url: str = None) -> List[Union[
+    types.TextContent, types.ImageContent, types.AudioContent, types.EmbeddedResource
+]]:
+    """Fetch LGE Static Analysis rule"""
+    fetcher = RuleFetcher()
+    return await fetcher.fetch_rule("lge_static", url)
+
 async def fetch_certcpp_rule(url: str = None) -> List[Union[
     types.TextContent, types.ImageContent, types.AudioContent, types.EmbeddedResource
 ]]:
