@@ -61,7 +61,7 @@ def main(port: int, transport: str):
         ]:
             """Route tool calls to appropriate handler"""
             # Danh sách premium tools
-            premium_tools = ["convert_md", "get_interface", "analyze_requirement"]
+            premium_tools = ["convert_md", "get_interface"]
             
             # Kiểm tra premium cho các premium tools
             if name in premium_tools and not premium_enabled:
@@ -197,50 +197,50 @@ def main(port: int, transport: str):
                         "required": []
                     },                    
                 ),
-                types.Tool(
-                    name="detect_races",
-                    description="Detect potential race conditions in the codebase using src_dir.",
-                    inputSchema={
-                        "type": "object",
-                        "properties": {},
-                    },
-                ),
-                types.Tool(
-                    name="analyze_leaks",
-                    description="AI-powered memory leak detection in C++ codebase using src_dir.",
-                    inputSchema={
-                        "type": "object", 
-                        "properties": {},
-                    },
-                ),
-                types.Tool(
-                    name="analyze_resources",
-                    description="AI-powered resource leak detection in Linux C++ codebase using src_dir.",
-                    inputSchema={
-                        "type": "object",
-                        "properties": {},
-                    },
-                ),
-                types.Tool(
-                    name="reset_analysis",
-                    description="Reset analysis cache for fresh start",
-                    inputSchema={
-                        "type": "object", 
-                        "properties": {
-                            "analysis_type": {
-                                "type": "string",
-                                "description": "Type of analysis to reset (memory_analysis, race_analysis, resource_analysis, or 'all')",
-                                "enum": ["memory_analysis", "race_analysis", "resource_analysis", "all"],
-                                "default": "all"
-                            },
-                            "directory": {
-                                "type": "string",
-                                "description": "Target directory (optional, uses src_dir if not provided)"
-                            }
-                        },
-                        "required": []
-                    },
-                ),
+                # types.Tool(
+                #     name="detect_races",
+                #     description="Detect potential race conditions in the codebase using src_dir.",
+                #     inputSchema={
+                #         "type": "object",
+                #         "properties": {},
+                #     },
+                # ),
+                # types.Tool(
+                #     name="analyze_leaks",
+                #     description="AI-powered memory leak detection in C++ codebase using src_dir.",
+                #     inputSchema={
+                #         "type": "object", 
+                #         "properties": {},
+                #     },
+                # ),
+                # types.Tool(
+                #     name="analyze_resources",
+                #     description="AI-powered resource leak detection in Linux C++ codebase using src_dir.",
+                #     inputSchema={
+                #         "type": "object",
+                #         "properties": {},
+                #     },
+                # ),
+                # types.Tool(
+                #     name="reset_analysis",
+                #     description="Reset analysis cache for fresh start",
+                #     inputSchema={
+                #         "type": "object", 
+                #         "properties": {
+                #             "analysis_type": {
+                #                 "type": "string",
+                #                 "description": "Type of analysis to reset (memory_analysis, race_analysis, resource_analysis, or 'all')",
+                #                 "enum": ["memory_analysis", "race_analysis", "resource_analysis", "all"],
+                #                 "default": "all"
+                #             },
+                #             "directory": {
+                #                 "type": "string",
+                #                 "description": "Target directory (optional, uses src_dir if not provided)"
+                #             }
+                #         },
+                #         "required": []
+                #     },
+                # ),
                 types.Tool(
                     name="report_rule_violation",
                     description="Generate .http (HTML) report for rule violations from all .md files in report_dir.",
@@ -261,6 +261,21 @@ def main(port: int, transport: str):
                     description="Generate .html report for resource leak analysis from .md files in report_dir.",
                     inputSchema={"type": "object", "properties": {}}
                 ),
+                types.Tool(
+                    name="analyze_requirement",
+                    description="analyze requirement from .md files in specified directory",
+                    inputSchema={
+                        "type": "object",
+                        "properties": {
+                            "dir": {
+                                "type": "string",
+                                "description": "path to directory containing .md files",
+                            }
+                        },
+                        "required": []
+                    }
+                ),
+                
             ]
             
             # Premium tools - chỉ thêm nếu premium enabled
@@ -312,21 +327,7 @@ def main(port: int, transport: str):
                             },
                             "required": []
                         }
-                    ),
-                    types.Tool(
-                        name="analyze_requirement",
-                        description="analyze requirement from .md files in specified directory",
-                        inputSchema={
-                            "type": "object",
-                            "properties": {
-                                "dir": {
-                                    "type": "string",
-                                    "description": "path to directory containing .md files",
-                                }
-                            },
-                            "required": []
-                        }
-                    ),
+                    ),                    
                 ]
                 tools.extend(premium_tools)
                 
@@ -367,6 +368,14 @@ def main(port: int, transport: str):
                     name="check_custom",
                     description="check code violations based on Custom rule guide for current file."
                 ),
+                types.Prompt(
+                    name="check_cim_static",
+                    description="Verify and analyze CIM (Coverity) static analysis results for current file."
+                ),
+                types.Prompt(
+                    name="check_cim_misra_cpp",
+                    description="Verify and analyze CIM (Coverity) MISRA C++ violation reports for current file."
+                ),
                 types.Prompt(
                     name="check_races",
                     description="Analyze potential race conditions in C++ codebase using AI.",
@@ -399,8 +408,18 @@ def main(port: int, transport: str):
                     name="reset_race_check",
                     description="Reset race analysis cache."
                 ),
+                types.Prompt(
+                    name="check_single_requirement",
+                    description="Verify whether current code implements a single user-provided requirement.",
+                    arguments=[
+                        types.PromptArgument(
+                            name="requirement_text",
+                            description="Free-form requirement to verify (e.g., 'The system shall encrypt data at rest.')",
+                            required=True,
+                        ),
+                    ],
+                )
             ]
-            
             # Premium prompts - chỉ thêm nếu premium enabled
             if premium_enabled:
                 premium_prompts = [
